@@ -15,7 +15,9 @@ use YAML::Tiny;
 
 use MySQL::Workbench::Parser::Table;
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
+
+has lint => ( is => 'ro', default => sub { 1 } );
 
 has file   => (
     is       => 'ro',
@@ -104,8 +106,10 @@ sub _parse {
              my ($orig)      = $sql =~ m{^([A-Z]+)};
              my ($length)    = $sql =~ m{\( (\d+) \)}x;
              my ($precision) = $sql =~ m{\( (\d+,\d+) \)}x;
+             my ($args)      = $sql =~ m{\( (.+?) \)}x;
+             my $gui_name    = $type->findvalue( './value[@key="name"]' );
 
-             $datatypes{$name} = { name => $orig, length => $length, precision => $precision };
+             $datatypes{$name} = { name => $orig, length => $length, precision => $precision, gui_name => $gui_name, args => $args };
          }
     }
 
@@ -121,7 +125,7 @@ sub _parse {
         );
     }
 
-    $self->_lint( \@tables );
+    $self->_lint( \@tables ) if $self->lint;
 
     $self->_set_tables( \@tables );
 }
@@ -201,7 +205,7 @@ MySQL::Workbench::Parser - parse .mwb files created with MySQL Workbench
 
 =head1 VERSION
 
-version 1.06
+version 1.07
 
 =head1 SYNOPSIS
 
@@ -255,6 +259,10 @@ An array of L<MySQL::Workbench::Parser::Table> objects
 
 The L<DOM|https://metacpan.org/pod/XML::LibXML> created by L<XML::LibXML>.
 
+=item * lint
+
+If set to false, the linting isn't done (default: true)
+
 =back
 
 =head1 WARNINGS
